@@ -446,14 +446,11 @@ if (count($fielddefs) > 0)
 
 $categories = $this->GetCategories();
 $catarray = array();
-
-if (count($categories) > 0)
-  {
-    foreach ($categories as $fielddef)
-      {
-        $catarray[$fielddef->name] = $fielddef->id;
-      }
+if( is_array($categories) && count($categories) ) { 
+  foreach ($categories as $fielddef) {
+    $catarray[$fielddef->name] = $fielddef->id;
   }
+}
 
 #Display template
 $smarty->assign('startform', $this->CreateFormStart($id, 'addproduct', $returnid, 'post', 'multipart/form-data'));
