@@ -60,6 +60,9 @@ $name = '';
 $extra1 = '';
 $extra2 = '';
 $description = '';
+$destdir = cms_join_path($gCms->config['uploads_path'],$this->GetName(),
+			 'hierarchy');
+
 
 #
 # Get the values from the database
@@ -110,9 +113,6 @@ if( isset($params['submit']) )
 
     if( !$error )
       {
-	$destdir = cms_join_path($gCms->config['uploads_path'],$this->GetName(),
-				 'hierarchy');
-
 	// handle image delete first
 	if( isset($params['deleteimg']) )
 	  {
@@ -170,6 +170,8 @@ $smarty->assign('name',$name);
 $smarty->assign('extra1',$extra1);
 $smarty->assign('extra2',$extra2);
 $smarty->assign('image',$image);
+$image_url = $gCms->config['uploads_url'].'/'.$this->GetName()."/hierarchy/$image";
+$smarty->assign('image_url',$image_url);
 $smarty->assign('description',$description);
 if( $this->GetPreference('autowatermark') == 'adjustable' )
 {
