@@ -47,83 +47,118 @@ if( isset($params['summarypage']) )
       {
 	$summarypage = $returnid;
       }
-    unset($params['summarypage']);
   }
 
+$hierpage = $returnid;
+$tmp = $this->GetPreference('hierpage');
+if( $tmp > 0 ) {
+  $hierpage = $tmp;
+}
+if( isset($params['hierarchypage']) ) {
+  $tmp = $this->resolve_alias_or_id($params['hierarchy']);
+  if( $tmp ) { 
+    $hierpage = $tmp;
+  }
+}
+
 if( !function_exists('products_byhierarchy_postprocess') )
   {
-    function products_byhierarchy_postprocess(&$data,$params,$summarypage,$thispage)
+    function products_byhierarchy_postprocess(&$data,$params,$summarypage,$hierpage)
     {
-      if( is_array($data) )
-	{
-	  $config = cmsms()->GetConfig();
-	  $module = cge_utils::get_module('Products');
-	  $imgdir = cms_join_path($config['uploads_path'],$module->GetName(),'hierarchy');
+      if( is_array($data) ) {
+	$config = cmsms()->GetConfig();
+	$module = cge_utils::get_module('Products');
+	$imgdir = cms_join_path($config['uploads_path'],$module->GetName(),'hierarchy');
 
-	  for( $i = 0; $i < count($data); $i++ )
-	    {
-	      $rec =& $data[$i];
+	for( $i = 0; $i < count($data); $i++ ) {
+	  $rec =& $data[$i];
 
-	      $tn = cms_join_path($imgdir,'thumb_'.$rec['image']);
-	      if( file_exists($tn) )
-		{
-		  $rec['thumbnail'] = 'thumb_'.$rec['image'];
-		}
+	  $tn = cms_join_path($imgdir,'thumb_'.$rec['image']);
+	  if( file_exists($tn) ) {
+	    $rec['thumbnail'] = 'thumb_'.$rec['image'];
+	  }
 	      
-	      $tn = cms_join_path($imgdir,'preview_'.$rec['image']);
-	      if( file_exists($tn) )
-		{
-		  $rec['preview'] = 'preview_'.$rec['image'];
-		}
+	  $tn = cms_join_path($imgdir,'preview_'.$rec['image']);
+	  if( file_exists($tn) ) {
+	    $rec['preview'] = 'preview_'.$rec['image'];
+	  }
 
-	      $parms = $params;
-	      $parms['parent'] = $rec['id'];
-	      $rec['down_url'] = $module->CreateURL('cntnt01','hierarchy',$thispage,$parms);
+	  if( !isset($rec['count']) ) $rec['count'] = 0;
 
-	      $parms = $params;
-	      $parms['hierarchyid'] = $rec['id'];
-	      $rec['url'] = $module->CreatePrettyLink('cntnt01','default',$summarypage,'',$parms,'',true);
+	  $parms = $params;
+	  $parms['parent'] = $rec['id'];
 
-	      if( isset($rec['children']) )
-		{
-		  products_byhierarchy_postprocess($rec['children'],$params,$summarypage,$thispage);
-		}
-	    }
+	  $rec['down_url'] = $module->CreateURL('cntnt01','hierarchy',$hierpage,$parms);
+
+	  $parms = $params;
+	  $parms['hierarchyid'] = $rec['id'];
+	  if( isset($parms['summarypage']) ) unset($parms['summarypage']);
+	  $rec['url'] = $module->CreatePrettyLink('cntnt01','default',$summarypage,'',$parms,'',true);
+
+	  if( isset($rec['children']) ) {
+	    products_byhierarchy_postprocess($rec['children'],$params,$summarypage,$hierpage);
+	  }
 	}
+      }
     }
   }
 
 
 $nodes = array();
 $parents = array(-1);
-if( isset($params['parent'] ) )
-  {
-    $parents = explode(',',$params['parent']);
-  }
-else if( isset($params['hierarchy']) )
-  {
-    $tmp = explode(',',$params['hierarchy']);
-    $tmp2 = array();
-    foreach( $tmp as $one )
-      {
-	$tmp2[] = "'".trim($one)."'";
+if( isset($params['parent'] ) ) {
+  $parents = array((int)$params['parent']);
+  unset($params['parent']);
+ }
+else if( isset($params['parents']) ) {
+  $tmp = explode(',',$params['parents']);
+  $tmp2 = array();
+  $tmp3 = array();
+  $all_hierarchy = hierarchy_ops::get_all_hierarchy_info();
+  if( !is_array($all_hierarchy) || count($all_hierarchy) == 0 ) return; // nothing to do.
+  foreach( $tmp as $one ) {
+    $one = trim($one);
+    foreach( $all_hierarchy as $onehier ) {
+      if( is_numeric($one) && $onehier['id'] == $one && !in_array($one,$tmp3) ) {
+	$tmp2[] = $onehier;
+	$tmp3[] = $one;
+	break;
       }
-    $tmp2 = implode(',',$tmp2);
-    $query = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy
+      else if( $onehier['name'] == $one && !in_array($onehier['id'],$tmp3) ) {
+	$tmp2[] = $onehier;
+	$tmp3[] = $onehier['id'];
+	break;
+      }
+    }
+  }
+  if( !is_array($tmp2) || count($tmp2) == 0 ) return; // nothing to display.
+  $parents = $tmp2;
+  unset($params['parents']);
+  products_byhierarchy_postprocess($parents,$params,$summarypage,$hierpage);
+}
+else if( isset($params['hierarchy']) ) {
+  $tmp = explode(',',$params['hierarchy']);
+  $tmp2 = array();
+  foreach( $tmp as $one ) {
+    $tmp2[] = "'".trim($one)."'";
+  }
+  $tmp2 = implode(',',$tmp2);
+  $query = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy
                WHERE name IN ('.$tmp2.')';
-    $nodes = $db->GetCol($query);
-    $nodes = array_unique($nodes);
-  }
+  $nodes = $db->GetCol($query);
+  $nodes = array_unique($nodes);
+  unset($params['hierarchy']);
+}
 
-if( !count($parents) )
-  {
-    // nothing found to start with
-    return;
-  }
+if( !count($parents) ) {
+  // nothing found to start with
+  return;
+ }
 
 $data = array();
 if( count($nodes) )
   {
+    // this will only display the selected hierarchies (not including their children) that have products.
     $nodes = implode(',',$nodes);
     $query = 'SELECT ph.*,count(pr.id) AS count FROM '.cms_db_prefix().'module_products_hierarchy ph
                 LEFT OUTER JOIN '.cms_db_prefix().'module_products_prodtohier pth
@@ -134,28 +169,38 @@ if( count($nodes) )
                  AND ph.id IN ('.$nodes.')
                GROUP BY ph.id ORDER BY ph.hierarchy';
     $tmp = $db->GetArray($query);
-    products_byhierarchy_postprocess($tmp,$params,$summarypage,$returnid);
+    products_byhierarchy_postprocess($tmp,$params,$summarypage,$hierpage);
     $data = $tmp;
   }
 else
   {
-    foreach( $parents as $parent_id )
+    foreach( $parents as $one )
       {
+	$parent_id = '';
+	if( is_array($one) ) {
+	  $parent_id = $one['id'];
+	}
+	else if( is_int($one) ) {
+	  $parent_id = $one;
+	}
+
+	if( $parent_id == '' ) continue;
+
 	$tmp = product_utils::hierarchy_get_tree($parent_id);
 	if( is_array($tmp) && count($tmp) )
 	  {
-	    products_byhierarchy_postprocess($tmp,$params,$summarypage,$returnid);
-	    $data[] = $tmp;
+	    products_byhierarchy_postprocess($tmp,$params,$summarypage,$hierpage);
+	    if( is_array($one) ) {
+	      $one['children'] = $tmp;
+	      $data[] = $one;
+	    }
+	    else {
+	      $data[] = $tmp;
+	    }
 	  }
       }
   }
 
-// if( !count($data) )
-//   {
-//     // nothing found in results
-//     return;
-//   }
-
 $hierdata = '';
 if( count($data) == 1 && empty($nodes) )
   {
