@@ -1,13 +1,11 @@
 <?php  /* -*- Mode: PHP; tab-width: 4; c-basic-offset: 2 -*- */
 #BEGIN_LICENSE
 #-------------------------------------------------------------------------
-# Module: Products (c) 2008 by Robert Campbell 
+# Module: Products (c) 2012 by Robert Campbell 
 #         (calguy1000@cmsmadesimple.org)
 #  An addon module for CMS Made Simple to allow users to create, manage
 #  and display products in a variety of ways.
 # 
-# Version: 1.1.5
-#
 #-------------------------------------------------------------------------
 # CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
 # This project's homepage is: http://www.cmsmadesimple.org
@@ -80,24 +78,6 @@ function products_BuildHierarchyList(&$mod)
 }
 
 
-function products_CreateHierarchyDropdown(&$mod,$id,$name,$selectedvalue)
-{
-  $db = $mod->GetDb();
-  $list = array();
-  $list[$mod->Lang('any')] = '';
-  $query = 'SELECT * FROM '.cms_db_prefix().'module_products_hierarchy
-               ORDER by hierarchy';
-  $dbresult = $db->Execute($query);
-  while( $dbresult && $row = $dbresult->FetchRow() )
-    {
-      //$list[$row['long_name']] = $row['long_name'];
-      $list[$row['long_name']] = $row['id'];
-    }
-
-  return $mod->CreateInputDropdown($id,$name,$list,-1,$selectedvalue);
-}
-
-
 function products_GetTypesDropdown( &$mod, $id, $name, $selected = '', $addtext = '', 
 				    $selectone = false )
 {
