@@ -82,6 +82,7 @@ $lang['error_missingparam'] = 'En n&ouml;dv&auml;ndig parameter saknas eller &au
 $lang['error_nameused'] = 'Ett objekt med det namnet anv&auml;nds redan';
 $lang['error_nofieldtype'] = 'V&auml;lj f&auml;lt typ';
 $lang['error_noname'] = 'Du m&aring;ste uppge ett namn';
+$lang['error_onesubscriptionfield'] = 'Only one subscription field is allowed';
 $lang['error_permissiondenied'] = 'Nekat tillst&aring;nd';
 $lang['error_product_aliasused'] = 'Det specificerade alias anv&auml;nds redan';
 $lang['error_product_nameused'] = 'En produkt med det namnet finns redan';
@@ -89,6 +90,9 @@ $lang['error_product_notfound'] = 'Den beg&auml;rda produkten kunde inte hittas'
 $lang['error_product_skuused'] = 'SKU-v&auml;rdet anv&auml;nds redan av en annan produkt';
 $lang['error_price_adjustment'] = 'Ogiltig prisjusterings v&auml;rde f&ouml;r objektet %s';
 $lang['error_upload_failed'] = 'Uppladdnings fel: %s';
+$lang['expire_six_months'] = 'Efter 6 m&aring;nader';
+$lang['expire_one_year'] = 'Efter 1 &aring;r';
+$lang['expire_two_year'] = 'Efter 2 &aring;r';
 $lang['extra1'] = 'Extra f&auml;lt 1';
 $lang['extra2'] = 'Extra f&auml;lt 2';
 $lang['field'] = 'F&auml;lt';
@@ -158,7 +162,7 @@ $lang['id'] = 'ID';
 $lang['imagetext'] = 'Bild';
 $lang['image_handling_settings'] = 'Bildhanterings inst&auml;llningar';
 $lang['import_from_csv'] = 'Importera produkter fr&aring;n CSV-fil';
-$lang['inches'] = 'Inches';
+$lang['inches'] = 'Tum';
 $lang['include_children'] = 'Inkludera children?';
 $lang['info_alnumonly'] = 'Endast alfanumeriska tecken. Inga blanksteg, citattecken eller icke skrivelse / nummer kombinationer';
 $lang['info_attribtemplate'] = 'M&ouml;jliga variabler &auml;r: {$attrib_text},{$attrib_adjust},{$currency_symbol}';
@@ -214,6 +218,7 @@ $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist acti
 $lang['param_detailpage'] = 'Detta anger pageid eller alias som b&ouml;r anv&auml;ndas f&ouml;r att visa en detalj rapport.';
 $lang['param_detailtemplate'] = 'Den h&auml;r parametern anger den mall som ska anv&auml;ndas f&ouml;r hur detalj-l&auml;ge visas. Om inget v&auml;rde anges, d&aring; kommer den nuvarande standardmall av denna typ att anv&auml;ndas.';
 $lang['param_field'] = 'Used only in the <em>fieldlist</em> action, this parameter is required to specify the name of a user defined property to create a list from.';
+$lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
 $lang['param_hierarchy'] = 'Useful only in the <em>default</em> action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all products beloging to any parent in the hierarchy.';
 $lang['param_hierarchytemplate'] = 'Den h&auml;r parametern anger den mall som ska anv&auml;ndas f&ouml;r hierarkin displayen. Om inget v&auml;rde anges, d&aring; kommer den nuvarande standardmall av denna typ att anv&auml;ndas.';
 $lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
@@ -241,7 +246,6 @@ $lang['param_sortby'] = 'Applicable only in summary mode, this parameter determi
 $lang['param_sorttype'] = 'Applicable only to the default summary view, this parameter is used to convert the values to another type for sorting.  valid values are STRING,SIGNED and UNSIGNED.  If not supplied the default STRING type is assumed.';
 $lang['param_summarypage'] = 'Applicable only to the action=hierarchy, allows specifying a page id or alias that will be used for any links to summjary view';
 $lang['param_summarytemplate'] = 'Den h&auml;r parametern anger den mall som ska anv&auml;ndas f&ouml;r sammanfattnings l&auml;ge. Om inget v&auml;rde anges, d&aring; kommer den nuvarande standardmall av denna typ att anv&auml;ndas.';
-$lang['param_useoldhierarchy'] = 'Use old hierarchy mode which generates a flat list of hierarchies below the current level.  This mode is deprecated and will be removed at a later date.';
 $lang['parent'] = 'F&ouml;reg&aring;ende';
 $lang['postinstall'] = 'Products modulen &auml;r nu installerad';
 $lang['postuninstall'] = 'Products modulen &auml;r nu borttagen samt all tillh&ouml;rande data';
@@ -284,6 +288,7 @@ $lang['prompt_delimiter'] = 'F&auml;lt avgr&auml;nsare';
 $lang['prompt_detailpage'] = 'Standard detaljsida';
 $lang['prompt_detailsfor'] = 'Detaljer f&ouml;r %s';
 $lang['prompt_duplicateproducts'] = 'Hur man hanterar duplikat produkter?';
+$lang['prompt_false'] = 'Falsk';
 $lang['prompt_handleimages'] = 'Hantera bilder?';
 $lang['prompt_imagepath'] = 'Bilds&ouml;kv&auml;g';
 $lang['prompt_lengthunits'] = 'L&auml;ngdenheter';
@@ -298,6 +303,7 @@ $lang['prompt_products_matching'] = 'Produkter matchar %s';
 $lang['prompt_summarysortorder'] = 'Standard sorteringsordning i sammandrags l&auml;ge';
 $lang['prompt_summarysorting'] = 'Standard sorteringsordning i f&auml;ltens sammandrags l&auml;ge';
 $lang['prompt_template'] = 'Mallens k&auml;lla';
+$lang['prompt_true'] = 'Sann';
 $lang['prompt_urlprefix'] = 'Prefix att anv&auml;nda p&aring; alla webbadresser som &auml;r inriktad p&aring; denna modulen';
 $lang['prompt_use_detailpage_for_search'] = 'Anv&auml;nd den h&auml;r sidan f&ouml;r s&ouml;kresultat f&ouml;r <em> (&aring;sidos&auml;tter s&ouml;kresultat sidparametern i modulen) </ em>';
 $lang['prompt_usehierpathurls'] = 'Use Hierarchy Path in Product Detail URLS';
@@ -321,6 +327,17 @@ $lang['sort_by'] = 'Sortera';
 $lang['sort_order'] = 'Sorteringsorder';
 $lang['status'] = 'Status ';
 $lang['submit'] = 'Spara';
+$lang['subscription'] = 'Subscription';
+$lang['subscr_expiry'] = 'Expiry';
+$lang['subscr_expiry2'] = 'Expires';
+$lang['subscr_monthly'] = 'Monthly';
+$lang['subscr_delperiod'] = 'Delivery Frequency';
+$lang['subscr_delperiod2'] = 'Levererad';
+$lang['subscr_payperiod'] = 'Payment Frequency';
+$lang['subscr_payperiod2'] = 'Betald';
+$lang['subscr_quarterly'] = 'Quarterly';
+$lang['subscr_semianually'] = 'Semi Anually';
+$lang['subscr_yearly'] = '&Aring;rlig';
 $lang['summarytemplates'] = 'Summeringsmallar';
 $lang['summarytemplate_addedit'] = 'L&auml;gg till/redigera en summeringsmall';
 $lang['taxable'] = 'Beskattningsbara';
@@ -344,9 +361,9 @@ $lang['viewable_fields'] = 'V&auml;lj anpassade f&auml;lt f&ouml;r att visa i ta
 $lang['watermark_location'] = 'Vattenm&auml;rkets placering';
 $lang['weight'] = 'Vikt';
 $lang['yes'] = 'Ja?';
-$lang['utma'] = '156861353.906052642.1267835734.1280424990.1280441159.148';
-$lang['utmz'] = '156861353.1280424990.147.9.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/|utmcmd=referral';
-$lang['qca'] = 'P0-1605183070-1267835733865';
+$lang['utma'] = '156861353.622613290.1282068801.1285618628.1285621370.19';
+$lang['utmz'] = '156861353.1284652314.14.4.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['qca'] = 'P0-1267218368-1282068801788';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utmb'] = '156861353.2.10.1285621370';
 ?>
\ No newline at end of file
