@@ -38,11 +38,39 @@
 #END_LICENSE
 
 
-class product_ops
+final class product_ops
 {
   static private $_fielddefs;
   static private $_prodhier;
+  static private $_product_cache;
 
+  static public function set_product($product)
+  {
+    if( !is_array($product) || !isset($product['id']) ) return;
+    if( !is_array(self::$_product_cache) ) self::$_product_cache = array();
+    self::$_product_cache[$product['id']] = $product;
+  }
+
+  static public function get_product($product_id)
+  {
+    if( is_array(self::$_product_cache) && isset(self::$_product_cache[$product_id]) ) {
+      return self::$_product_cache[$product_id];
+    }
+
+    $query = new products_query();
+    $query['product_id'] = $product_id;
+    $results = new products_resultset($query);
+    if( $results->RecordCount() > 1 ) {
+      throw new Exception('INTERNAL ERROR: More than one product with the id '.$product_id);
+    }
+    
+    if( !is_array(self::$_product_cache) ) self::$_product_cache = array();
+    self::$_product_cache[$product_id] = $results->fields;
+    if( $product_id != $results->fields['id'] ) {
+      throw new Exception('INTERNAL ERROR: query did not return information for '.$product_id);
+    }
+    return self::$_product_cache[$product_id];
+  }
 
   static public function is_valid_category($name)
   {
@@ -154,9 +182,9 @@ class product_ops
   static public function pretty_url($pid,$returnid = '')
   {
     $module = cms_utils::get_module('Products');
-    $product = $module->GetProduct($pid);
+    $product = self::get_product($pid);
     if( !$product ) return;
-    $db = $module->GetDB();
+    $db = cmsms()->GetDB();
     
     $usereturnid = true;    
     if( $returnid == -1 )
@@ -233,6 +261,7 @@ class product_ops
 	$query = 'SELECT hierarchy_id FROM '.cms_db_prefix().'module_products_prodtohier
               WHERE product_id = ? LIMIT 1';
 	$hier_id = $db->GetOne($query,array($productid));
+	if( $hier_id <= 0 ) return FALSE;
 	if( !is_array(self::$_prodhier) )
 	  {
 	    self::$_prodhier = array();
@@ -243,6 +272,7 @@ class product_ops
   }
 
 
+  /* deprecated */
   public static function get_product_hierarchy_path($productid)
   {
     $hier_id = self::get_product_hierarchy_id($productid);
@@ -253,20 +283,12 @@ class product_ops
   }
 
 
+  /* deprecated */
   public static function create_hierarchy_breadcrumb($id,$product_id, $hierpage, $delim = ' &gt; ')
   {
-    $module = cms_utils::get_module('Products');
-    $tmp = array();
-    $hierarchy_path = self::get_product_hierarchy_path($product_id);
-    if( !$hierarchy_path ) return false;
-    foreach( $hierarchy_path as $one )
-      {
-	$info = hierarchy_ops::get_hierarchy_info($one);
-	$link = $module->CreatePrettyLink($id,'hierarchy',$hierpage,
-					  $info['name'],array('parent'=>$info['id']));
-	$tmp[] = $link;
-      }
-    return implode($delim,$tmp);
+    $hier_id = self::get_product_hierarchy_id($product_id);
+    if( $hier_id <= 0 ) return FALSE;
+    return hierarchy_ops::get_breadcrumb($id,$hier_id,$hierpage,$delim);
   }
 
 
@@ -372,7 +394,40 @@ class product_ops
     return $result;
   }
 
-  
+
+  public static function get_product_attributes_full($product_id)
+  {
+    $db = cmsms()->GetDb();
+    $data = array();
+
+    $query = 'SELECT * FROM '.cms_db_prefix().'module_products_attribsets
+              WHERE product_id = ?';
+    $tmp = $db->GetArray($query,array($product_id));	
+
+    $tmp2 = cge_array::extract_field($tmp,'attrib_set_id');
+    $q2 = 'SELECT * FROM '.cms_db_prefix().'module_products_attributes
+            WHERE attrib_set_id IN ('.implode(',',$tmp2).') ORDER BY attrib_set_id ASC';
+    $tmp3 = $db->GetArray($q2);
+
+    for( $i = 0; $i < count($tmp); $i++ )
+      {
+	$row =& $tmp[$i];
+
+	$attribs = array();
+	for( $j = 0; $j < count($tmp3); $j++ )
+	  {
+	    $row2 =& $tmp3[$j];
+	    if( $row2['attrib_set_id'] < $row['attrib_set_id'] ) continue;
+	    if( $row2['attrib_set_id'] > $row['attrib_set_id'] ) break;
+
+	    $attribs[$row2['attrib_text']] = $row2;
+	  }
+	$data[$row['attrib_set_name']] = $attribs;
+      }
+
+    if( !count($data) ) return false;
+    return $data;
+  }
 } // class
 
 
